#!/bin/bash

BASEDIR=$(dirname "$0")
echo "running from directory $BASEDIR"

export KAFKA_OPTS=""
source ${BASEDIR}/kafka.properties
file=${BASEDIR}/topics.csv

createTopic()
{
  TOPIC=$1
  RETENTION_POLICY=$2
  ${KAFKA_BIN_HOME}/kafka-topics --list --zookeeper ${ZOOKEEPER_CONNECT} | grep -x ${TOPIC} 2>&1 >/dev/null
  retval=`echo $?`
  if [[ "${retval}" == 0 ]]; then
    retval=1
    return "$retval"
  fi

  ${KAFKA_BIN_HOME}/kafka-topics --create --zookeeper ${ZOOKEEPER_CONNECT} --replication-factor ${REPLICATION_FACTOR} --partitions ${PARTITIONS} --topic ${TOPIC} --config cleanup.policy=${RETENTION_POLICY}
  retval=`echo $?`
  if [[ "${retval}" != 0 ]]; then
    #statements
    retval=2
    return "${retval}"
  fi
  return "$retval"
}

## Main script starts here
IFS=
sed 1d $file | while read line
do
topic=`echo $line|cut -d',' -f1`
retention_policy=`echo $line|cut -d',' -f2`
createTopic $topic $retention_policy
CREATETOPIC_RETURN_CODE=$?
if [ "$CREATETOPIC_RETURN_CODE" -eq "1" ]; then
  echo "Topic $topic already exists"
elif [ "$CREATETOPIC_RETURN_CODE" -eq "2" ]; then
   echo "Create topic failed on $topic"
else
  echo "Topic $topic created."
fi
done
