#!/bin/bash
BASEDIR=/usr/share/cts-kubectl-config
CORECONFDIR="$BASEDIR/Images/conf"
APPCONFDIR="$BASEDIR/Images/conf/netq-apps"


#Loading the docker images on system

setupsearchstatefulset ()
{
    echo -en "Setting up the Statefulset Pod: netq-app-search"
    kubectl create -f "$BASEDIR/Images/conf/netq-app-search/configmap.yml"
    kubectl create -f "$BASEDIR/Images/conf/netq-app-search/persistent-vol.yml"
    sleep 5
    kubectl create -f "$BASEDIR/Images/conf/netq-app-search/pv-claim.yml"
    sleep 5
    kubectl create -f "$BASEDIR/Images/conf/netq-app-search/service.yml"
    kubectl create -f "$BASEDIR/Images/conf/netq-app-search/statefulset.yml"
    kubectl create -f "$BASEDIR/Images/conf/netq-app-search/servicemonitor.yml"
    sleep 5
    echo -en "Finished Setting up statefulset Pod: netq-app-search \n"
}

# This Sets up the kafka-connect and schema-registry.
setupconnectset=('kafka-connect' 'cp-schema-registry');

setupConnectors ()
{
 for connectset in "${setupconnectset[@]}"; do
   echo -en "Setting up the statefulset Connectors.... \n"
   kubectl create -f "$BASEDIR/Images/conf/$connectset/configmap.yml"
   kubectl create -f "$BASEDIR/Images/conf/$connectset/deploy.yml"
   kubectl create -f "$BASEDIR/Images/conf/$connectset/service.yml"
   kubectl create -f "$BASEDIR/Images/conf/$connectset/servicemonitor.yml"
   sleep 5
 done
   echo -en "Finished Setting up Pod: $statefulpod \n"
}


#Onboarding the netq-api-gwatway
apiset=('netq-endpoint-gateway' 'netq-api-gateway' 'netq-opta' 'netq-app-healthdashboard');

setupAPIGW ()
{
 for apisetpod in "${apiset[@]}"; do
   echo -en "Setting the application set pod: $apisetpod \n"
   kubectl create -f "$BASEDIR/Images/conf/$apisetpod/configmap.yml"
   kubectl create -f "$BASEDIR/Images/conf/$apisetpod/secret.yml"
   kubectl create -f "$BASEDIR/Images/conf/$apisetpod/deploy.yml"
   kubectl create -f "$BASEDIR/Images/conf/$apisetpod/service.yml"
   kubectl create -f "$BASEDIR/Images/conf/$apisetpod/servicemonitor.yml"
   sleep 5
 done
   echo -en "Finished Setting up Pod: $appsetpod \n"
}

setupInstaller ()
{
   kubectl create -f "$BASEDIR/Images/conf/netq-installer/deploy.yml"
   kubectl create -f "$BASEDIR/Images/conf/netq-installer/service.yml"
}

setupGUI ()
{
   echo -en "Setting the application set pod: netq-gui \n"
   kubectl create -f "$BASEDIR/Images/conf/netq-gui/configmap.yml"
   kubectl create -f "$BASEDIR/Images/conf/netq-gui/deploy.yml"
   kubectl create -f "$BASEDIR/Images/conf/netq-gui/service.yml"
   kubectl create -f "$BASEDIR/Images/conf/netq-gui/servicemonitor.yml"
   kubectl create configmap netq-ssl-certs --from-file=$BASEDIR/Images/conf/netq-gui/ssl/
   kubectl create configmap netq-help --from-file=$BASEDIR/Images/conf/netq-gui/help/
   echo -en "Finished Setting up Pod: netq-gui \n"
}

###Main


# Onboard all other netq-apps

setupnetqapps ()
{
  echo -en "Onboard all NetQ apps"
  cd $APPCONFDIR
  netqapplist=`ls -d */ | cut -f1 -d'/'`
  for netqappname in $netqapplist; do
    if [ $netqappname == "python-netq-apps" ]; then
      continue
    else
      echo -en "Setting up the application pod $netqappname ...\n"
      kubectl create -f $netqappname/configmap.yml
      kubectl create -f $netqappname/deploy.yml
      kubectl create -f $netqappname/service.yml
      kubectl create -f $netqappname/servicemonitor.yml
      sleep 5
    fi
  done
  echo -en "Finished Setting up apps....\n"
}

setuppythonapps ()
{
  echo -en "Setting up the application pod python-netq-apps ...\n"
  kubectl create -f $BASEDIR/Images/conf/python-netq-apps/configmap.yml
  kubectl create -f $BASEDIR/Images/conf/python-netq-apps/deploy.yml
  kubectl create -f $BASEDIR/Images/conf/python-netq-apps/service.yml
  kubectl create -f $BASEDIR/Images/conf/python-netq-apps/servicemonitor.yml
  sleep 5
}

setupswagger ()
{
  echo -en "Setup swagger"
  cd $CORECONFDIR/swagger-ui
  kubectl create configmap swagger-ui-config --from-file=swagger.json
  kubectl create -f deploy.yml
  kubectl create -f service.yml
  echo -en "Done setting up swagger"
}

setupmetrics ()
{
  #####    node-exporter
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/node-exporter/service.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/node-exporter/clusterRole.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/node-exporter/clusterRoleBinding.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/node-exporter/daemonset.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/node-exporter/serviceAccount.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/node-exporter/serviceMonitor.yaml
  ####    kube-state-metrics
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/kube-state-metrics/deployment.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/kube-state-metrics/service.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/kube-state-metrics/serviceAccount.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/kube-state-metrics/serviceMonitor.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/kube-state-metrics/clusterRole.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/kube-state-metrics/clusterRoleBinding.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/kube-state-metrics/role.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/kube-state-metrics/roleBinding.yaml
  #####    grafana
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/grafana/deployment.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/grafana/service.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/grafana/dashboardDefinitions.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/grafana/dashboardDefinitionsNetqApi.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/grafana/dashboardDefinitionsKafkaConnect.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/grafana/dashboardDefinitionsZookeeper.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/grafana/serviceAccount.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/grafana/dashboardDatasources.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/grafana/dashboardSources.yaml
  #### prometheus
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/prometheus/persistent-vol.yml
  sleep 20
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/prometheus/deployment.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/prometheus/service.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/prometheus/serviceAccount.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/prometheus/clusterRole.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/prometheus/clusterRoleBinding.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/prometheus/roleConfig.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/prometheus/roleBindingConfig.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/prometheus/roleSpecificNamespaces.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/prometheus/roleBindingSpecificNamespaces.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/prometheus/rules.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/prometheus/serviceMonitor.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/prometheus/serviceMonitorKubelet.yaml
}

echo -en "Started execution of the Script"
setupInstaller
setupAPIGW
setupswagger
setupGUI
setupConnectors
setupsearchstatefulset
setuppythonapps
setupnetqapps
setupmetrics
echo -en "Finished setting up the apps"
