#!/bin/bash
BASEDIR=/usr/share/cts-kubectl-config
CORECONFDIR="$BASEDIR/Images/conf"
APPCONFDIR="$BASEDIR/Images/conf/netq-apps"


#Setting up Metrics Dashboard

setupmetricscrd ()
{
  echo -en "Setting up Metrics Dashboard for environment...\n"
  kubectl create ns monitoring
  ######    crd
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/crd/alertmanager.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/crd/prometheus.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/crd/prometheusrule.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/crd/servicemonitor.yaml
  #####    prometheus-operator
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/prometheus-operator/deployment.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/prometheus-operator/service.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/prometheus-operator/serviceAccount.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/prometheus-operator/serviceMonitor.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/prometheus-operator/clusterRole.yaml
  kubectl create -f $BASEDIR/Images/conf/netq-metrics-dashboard/prometheus-operator/clusterRoleBinding.yaml
  sleep 5
  echo -en "End of Setting up Metric Dashboard ....\n"
}


#Setting up the logs for the environment.
setuplogs ()
{
  echo -en "Setting up logs for environment...\n"
  kubectl create -f "$BASEDIR/Images/conf/logs/persistent-vol.yml"
  sleep 20
  kubectl create -f "$BASEDIR/Images/conf/logs/pv-claim.yml"
  sleep 5
  kubectl create -f "$BASEDIR/Images/conf/logs/serviceAccount.yml"
  kubectl create -f "$BASEDIR/Images/conf/logs/configmap.yml"
  kubectl create -f "$BASEDIR/Images/conf/logs/daemonset.yml"
}


#Setting up statefulset platform.
statefulsetPod=('cassandra' 'zookeeper' 'kafka');

setupstatefulset ()
{
  for statefulpod in "${statefulsetPod[@]}"; do
    echo -en "Setting up the Statefulset Pod: $statefulpod"
    kubectl create -f "$BASEDIR/Images/conf/$statefulpod/configmap.yml"
    kubectl create -f "$BASEDIR/Images/conf/$statefulpod/persistent-vol.yml"
    sleep 20
    kubectl create -f "$BASEDIR/Images/conf/$statefulpod/pv-claim.yml"
    sleep 5
    kubectl create -f "$BASEDIR/Images/conf/$statefulpod/service.yml"
    kubectl create -f "$BASEDIR/Images/conf/$statefulpod/statefulset.yml"
    kubectl create -f "$BASEDIR/Images/conf/$statefulpod/servicemonitor.yml"
    sleep 5
  done
    echo -en "Finished Setting up statefulset Pod: $statefulpod \n"
}


updateCassandraSchema ()
{
   echo -en "Sleeping 30 seconds for cassandra pod to be up\n"
   echo -en "If the below steps fail, check if cassandra-0 pod is up or not and rerun the cmds after the pod is up\n"
   i=0
   max=5
   while [ $i -lt $max ]
   do
      sleep 30

      kubectl cp $BASEDIR/Images/conf/cassandra/schema cassandra-0:/tmp
      ret=$?

      if [ $ret -eq 0 ]; then
         break
      else
         i=$((i+1))
      fi
   done

   if [ $i -eq $max ]; then
      echo "Cassandra faield to come up."
      exit 1
   fi
   kubectl exec cassandra-0 -- bash -c 'cqlsh -f /tmp/schema/keyspace/keyspace_dev.cql'
   kubectl exec cassandra-0 -- bash -c 'cqlsh -f /tmp/schema/baseline/schema.cql'
   kubectl exec cassandra-0 -- bash -c 'cqlsh -f /tmp/schema/baseline/event_catalog.cql'
}

createkafkatopics ()
{
  echo -en "Sleeping 30 seconds for kafka pod to be up\n"
  echo -en "If the below steps fail, check if kafka-broker-0 pod is up or not and rerun the cmds after the pod is up\n"
  sleep 30
  kubectl cp  $BASEDIR/Images/conf/kafkatopics kafka-broker-0:/tmp
  kubectl exec kafka-broker-0 -- bash -c '/tmp/kafkatopics/create-kafka-topic.sh 2>&1'
}




###Main

echo -en "Started execution of the Script"

loadallimages
setupmetricscrd
setuplogs
setupstatefulset
updateCassandraSchema
createkafkatopics
