#!/bin/sh

set -ex

for app in zookeeper/data zookeeper/log cassandra kafka prometheus var/lib/docker netq-app-search/index box; do
  mkdir -p "/mnt/$app"
  chmod 777 -R "/mnt/$app"
done
# Create directory in /var/log/netq for all netq components
mkdir -p /var/log/netq

kube_admins="cumulus root"

i=0
max=60
while [ $i -lt $max ]
do
    ip=$(ip -4 -br addr show eth0 | awk '{print $NF}' | cut -d '/' -f 1)
    if expr "$ip" : '[0-9][0-9]*\.[0-9][0-9]*\.[0-9][0-9]*\.[0-9][0-9]*$' >/dev/null; then
       break
    else
       echo "Waiting on IP address for eth0"
       sleep 60
       i=$((i+1))
    fi
done

if [ $i -eq 60 ]; then
   echo "Failed to find assigned IP address for eth0"
   exit 1
fi

kubeadm --pod-network-cidr=10.244.0.0/16 --apiserver-advertise-address=$ip --kubernetes-version=v1.11.5 init

# set up admin users with non-sudo access to kubernetes
for user in $kube_admins; do
	homedir="$(getent passwd "$user" | cut -d: -f6)"
	if test -d "$homedir"; then
		rm -rf "$homedir/.kube/"
		mkdir -p "$homedir/.kube"
		cp -i /etc/kubernetes/admin.conf "$homedir/.kube/config"
		chown "$user:$user" "$homedir/.kube/config"
	fi
done

sudo -u cumulus kubectl apply -f /usr/share/cts-kubectl-config/kube-flannel.yml
sudo -u cumulus kubectl taint node `hostname` node-role.kubernetes.io/master:NoSchedule-

sudo -u cumulus /usr/share/cts-kubectl-config/setupImages_Core.sh
sudo -u cumulus /usr/share/cts-kubectl-config/setupImages_Apps.sh

cp /usr/share/cts-kubectl-config/netq.yml /etc/netq/config.d/netq.yml
systemctl restart netqd

# initial setup of kubernetes. Not idempotent; should only be run on first boot.

/bin/systemctl --no-block disable cts-kubectl-config.service
